==> kvlibsdk_5_26_679.tar.gz: kvlibsdk/kvlclib/KvaLogReader_Mdf4.h <==
/*
**             Copyright 2017 by Kvaser AB, Molndal, Sweden
**                         http://www.kvaser.com
**
** This software is dual licensed under the following two licenses:
** BSD-new and GPLv2. You may use either one. See the included
** COPYING file for details.
**
** License: BSD-new
** ==============================================================================
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the <organization> nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
** IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**
**
** License: GPLv2
** ==============================================================================
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
**
**
** IMPORTANT NOTICE:
** ==============================================================================
** This source code is made available for free, as an open license, by Kvaser AB,
** for use with its applications. Kvaser AB does not accept any liability
** whatsoever for any third party patent or other immaterial property rights
** violations that may result from any usage of this source code, regardless of
** the combination of source code and various applications that it can be used
** in, or with.
**
** -----------------------------------------------------------------------------
*/

#ifndef KVALOGREADER_MDF4_H_
#define KVALOGREADER_MDF4_H_

#include "KvaLogReader.h"
#include "mdf.h"
#include "mdf4base.h"
#include <string>
#include "kvaDbLib.h"

class MdfChannelGroup;

class KvaLogReader_Mdf4 : public KvaLogReader {
  friend class MdfChannelGroup;
  friend class MdfDataChannel;
  friend class MdfBlockBase;

  private:
    unsigned long     current_eventno;
    unsigned long     current_frameno;
    KvlcStatus interpret_event(imLogData *logEvent);
    KvlcStatus create_channels(void);
    void read_block(void *block, size_t len);
    void goto_block(MDF_LINK64 link);
    void peek_block_head(void *block, size_t len);
    MDF_LINK64 get_link(void);
    KVMDF_TIMESTAMP mStartDate;
    bool mFindChannels;
    enum StateType {SEND_TRIGGER, SEND_CLOCK, SEND_FRAMES};
    StateType state;
    bool mUseSavedFrame;
    imLogData mLogEvent;
    unsigned int mNextChannelIndex;
    KvlcStatus get_attachment(void * atBlock);
    KvlcStatus read_data_list_block(MdfChannelGroup *pCh, int type);


  protected:
    static std::string mDatabaseName;
    static KvaDbHnd mDatabaseHnd;
    static bool mCheckSignals;

  public:
    KvaLogReader_Mdf4();
    ~KvaLogReader_Mdf4();

    KvlcStatus interpret_event(void *event,
                                   imLogData *logEvent)
    {
      return interpret_event((char*) event, logEvent);
    }

    KvlcStatus read_row(imLogData *logEvent);
    unsigned long event_count();
    bool isBinary() { return true; }
    KvlcStatus next_file();
    KvlcStatus verify_signals();

};

#endif /*KVALOGREADER_MDF4_H_*/

==> kvlibsdk_5_35_477.tar.gz: kvlibsdk/kvlclib/KvaLogReader_Mdf4.h <==
/*
**             Copyright 2017 by Kvaser AB, Molndal, Sweden
**                         http://www.kvaser.com
**
** This software is dual licensed under the following two licenses:
** BSD-new and GPLv2. You may use either one. See the included
** COPYING file for details.
**
** License: BSD-new
** ==============================================================================
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the <organization> nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
** IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**
**
** License: GPLv2
** ==============================================================================
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
**
**
** IMPORTANT NOTICE:
** ==============================================================================
** This source code is made available for free, as an open license, by Kvaser AB,
** for use with its applications. Kvaser AB does not accept any liability
** whatsoever for any third party patent or other immaterial property rights
** violations that may result from any usage of this source code, regardless of
** the combination of source code and various applications that it can be used
** in, or with.
**
** -----------------------------------------------------------------------------
*/

#ifndef KVALOGREADER_MDF4_H_
#define KVALOGREADER_MDF4_H_

#include "KvaLogReader.h"
#include "mdf.h"
#include "mdf4base.h"
#include <string>
#include "kvaDbLib.h"

class MdfChannelGroup;

class KvaLogReader_Mdf4 : public KvaLogReader {
  friend class MdfChannelGroup;
  friend class MdfDataChannel;
  friend class MdfBlockBase;

  private:
    uint64            current_eventno;
    unsigned long     current_frameno;
    KvlcStatus interpret_event(imLogData *logEvent);
    KvlcStatus create_channels(void);
    void read_block(void *block, size_t len);
    void goto_block(MDF_LINK64 link);
    void peek_block_head(void *block, size_t len);
    MDF_LINK64 get_link(void);
    KVMDF_TIMESTAMP mStartDate;
    bool mFindChannels;
    enum StateType {SEND_TRIGGER, SEND_CLOCK, SEND_FRAMES};
    StateType state;
    bool mUseSavedFrame;
    imLogData mLogEvent;
    unsigned int mNextChannelIndex;
    KvlcStatus get_attachment(void * atBlock);
    KvlcStatus read_data_list_block(MdfChannelGroup *pCh, int type);


  protected:
    static std::string mDatabaseName;
    static KvaDbHnd mDatabaseHnd;
    static bool mCheckSignals;

  public:
    KvaLogReader_Mdf4();
    ~KvaLogReader_Mdf4();

    KvlcStatus interpret_event(void *event,
                                   imLogData *logEvent)
    {
      return interpret_event((char*) event, logEvent);
    }

    KvlcStatus read_row(imLogData *logEvent);
    uint64 event_count();
    bool isBinary() { return true; }
    KvlcStatus next_file();
    KvlcStatus verify_signals();

};

#endif /*KVALOGREADER_MDF4_H_*/
